////////////////////////////////////////////////////////////////////////////
//
// Copyright (c) 2012-2025 60East Technologies Inc., All Rights Reserved.
//
// This computer software is owned by 60East Technologies Inc. and is
// protected by U.S. copyright laws and other laws and by international
// treaties.  This computer software is furnished by 60East Technologies
// Inc. pursuant to a written license agreement and may be used, copied,
// transmitted, and stored only in accordance with the terms of such
// license agreement and with the inclusion of the above copyright notice.
// This computer software or any other copies thereof may not be provided
// or otherwise made available to any other person.
//
// U.S. Government Restricted Rights.  This computer software: (a) was
// developed at private expense and is in all respects the proprietary
// information of 60East Technologies Inc.; (b) was not developed with
// government funds; (c) is a trade secret of 60East Technologies Inc.
// for all purposes of the Freedom of Information Act; and (d) is a
// commercial item and thus, pursuant to Section 12.212 of the Federal
// Acquisition Regulations (FAR) and DFAR Supplement Section 227.7202,
// Government's use, duplication or disclosure of the computer software
// is subject to the restrictions set forth by 60East Technologies Inc..
//
////////////////////////////////////////////////////////////////////////////

package com.crankuptheamps.client.exception;

/**
 * Thrown when the AMPS server reports that a filter could not be
 * successfully processed.
 */

public class PublishFilterException extends CommandException
{
    private static final long serialVersionUID = 1L;
    private String _filter;
    private String _data;

    public PublishFilterException()
    {
        super("Publish filter didn't match any records.");
        _filter = "unknown";
        _data = "unknown";
    }

    public PublishFilterException(String filter_, String data_)
    {
        super("Publish filter \"" + filter_ + "\" didn't match any records so \"" + data_ + "\" didn't publish.");
        _filter = filter_;
        _data = data_;
    }

    public PublishFilterException(String filter_, String data_, Throwable t)
    {
        super("Publish filter \"" + filter_ + "\" didn't match any records so \"" + data_ + "\" didn't publish.", t);
        _filter = filter_;
        _data = data_;
    }

    public PublishFilterException(String msg)
    {
        super(msg);
    }
    
    public PublishFilterException(Throwable t)
    {
        super(t);
    }

    public PublishFilterException(String msg, Throwable t)
    {
        super(msg, t);
    }

    public String getFilter()
    {
        return _filter;
    }

    public String getData()
    {
        return _data;
    }
}
